@@ -92,14 +92,14 @@ void kpMainWindow::setupEditMenuActions ()
     d->actionCut = KStandardAction::cut (this, SLOT (slotCut()), ac);
     d->actionCopy = KStandardAction::copy (this, SLOT (slotCopy()), ac);
     d->actionPaste = KStandardAction::paste (this, SLOT (slotPaste()), ac);
-    d->actionPasteInNewWindow = ac->addAction ("edit_paste_in_new_window");
+    d->actionPasteInNewWindow = ac->addAction (QStringLiteral("edit_paste_in_new_window"));
     d->actionPasteInNewWindow->setText (i18n ("Paste in &New Window"));
     connect (d->actionPasteInNewWindow, &QAction::triggered,
              this, &kpMainWindow::slotPasteInNewWindow);
     ac->setDefaultShortcut (d->actionPasteInNewWindow, Qt::CTRL + Qt::SHIFT + Qt::Key_V);
 
     //d->actionDelete = KStandardAction::clear (this, SLOT (slotDelete()), ac);
-    d->actionDelete = ac->addAction ("edit_clear");
+    d->actionDelete = ac->addAction (QStringLiteral("edit_clear"));
     d->actionDelete->setText (i18n ("&Delete Selection"));
     connect (d->actionDelete, &QAction::triggered, this, &kpMainWindow::slotDelete);
 
@@ -107,11 +107,11 @@ void kpMainWindow::setupEditMenuActions ()
     d->actionDeselect = KStandardAction::deselect (this, SLOT (slotDeselect()), ac);
 
 
-    d->actionCopyToFile = ac->addAction ("edit_copy_to_file");
+    d->actionCopyToFile = ac->addAction (QStringLiteral("edit_copy_to_file"));
     d->actionCopyToFile->setText (i18n ("C&opy to File..."));
     connect (d->actionCopyToFile, &QAction::triggered, this, &kpMainWindow::slotCopyToFile);
 
-    d->actionPasteFromFile = ac->addAction ("edit_paste_from_file");
+    d->actionPasteFromFile = ac->addAction (QStringLiteral("edit_paste_from_file"));
     d->actionPasteFromFile->setText (i18n ("Paste &From File..."));
     connect (d->actionPasteFromFile, &QAction::triggered, this, &kpMainWindow::slotPasteFromFile);
 
@@ -157,7 +157,7 @@ void kpMainWindow::enableEditMenuDocumentActions (bool enable)
 // public
 QMenu *kpMainWindow::selectionToolRMBMenu ()
 {
-    return qobject_cast <QMenu *> (guiFactory ()->container ("selectionToolRMBMenu", this));
+    return qobject_cast <QMenu *> (guiFactory ()->container (QStringLiteral("selectionToolRMBMenu"), this));
 }
 
 //---------------------------------------------------------------------
